@@ -1,5 +1,4 @@
-
-if __name__ == '__main__':
+if __name__ == "__main__":
     from .netconsole import main
-    main()
 
+    main()
